@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -24,7 +24,7 @@ from . import Bytes
 class String(Bytes):
     @staticmethod
     def read(b: BytesIO, *args) -> str:
-        return super(String, String).read(b).decode()
+        return super(String, String).read(b).decode(errors="replace")
 
     def __new__(cls, value: str) -> bytes:
         return super().__new__(cls, value.encode())
