@@ -16,13 +16,17 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
+from .delete_user_profile_photos import DeleteUserProfilePhotos
 from .get_me import GetMe
 from .get_user_profile_photos import GetUserProfilePhotos
 from .get_users import GetUsers
+from .set_user_profile_photo import SetUserProfilePhoto
 
 
 class Users(
     GetUserProfilePhotos,
+    SetUserProfilePhoto,
+    DeleteUserProfilePhotos,
     GetUsers,
     GetMe
 ):
